@@ -32,9 +32,16 @@ Library for detecting the current OS, including detecting specific
 Linux distributions.
 """
 
+from __future__ import absolute_import
 from __future__ import print_function
 
 import codecs
+# to be removed after Ubuntu Xenial is out of support
+import sys
+if sys.version_info >= (3, 8):
+    import distro
+else:
+    import platform as distro
 import locale
 import os
 import platform
@@ -131,15 +138,18 @@ class LsbDetect(OsDetector):
     """
     def __init__(self, lsb_name, get_version_fn=None):
         self.lsb_name = lsb_name
-        if hasattr(platform, "linux_distribution"):
-            self.lsb_info = platform.linux_distribution(full_distribution_name=0)
-        elif hasattr(platform, "dist"):
-            self.lsb_info = platform.dist()
+        if hasattr(distro, "linux_distribution"):
+            self.lsb_info = distro.linux_distribution(full_distribution_name=0)
+        elif hasattr(distro, "dist"):
+            self.lsb_info = distro.dist()
         else:
             self.lsb_info = None
 
     def is_os(self):
-        return self.lsb_info is not None and self.lsb_info[0] == self.lsb_name
+        if self.lsb_info is None:
+            return False
+        # Work around platform returning 'Ubuntu' and distro returning 'ubuntu'
+        return self.lsb_info[0].lower() == self.lsb_name.lower()
 
     def get_version(self):
         if self.is_os():
@@ -200,10 +210,10 @@ class FdoDetect(OsDetector):
             if "VERSION" in self.release_info:
                 version = self.release_info["VERSION"]
                 # FDO style: works with Fedora, Debian, Suse.
-                if version.find("(") is not -1:
+                if '(' in version:
                     codename = version[version.find("(") + 1:version.find(")")]
                 # Ubuntu style
-                elif version.find(",") is not -1:
+                elif '"' in version:
                     codename = version[version.find(",") + 1:].lstrip(' ').split()[0]
                 # Indeterminate style
                 else:
@@ -255,6 +265,9 @@ class OpenSuse(OsDetector):
         raise OsNotDetected('cannot get version on this OS')
 
     def get_codename(self):
+        # /etc/SuSE-release is deprecated since 13.1
+        if self._release_file is None:
+            return ""
         if self.is_os() and os.path.exists(self._release_file):
             with open(self._release_file, 'r') as fh:
                 os_list = fh.read().strip().split('\n')
@@ -724,6 +737,7 @@ OS_UBUNTU = 'ubuntu'
 OS_CLEARLINUX = 'clearlinux'
 OS_NIXOS = 'nixos'
 OS_WINDOWS = 'windows'
+OS_ZORIN =  'zorin'
 
 OsDetect.register_default(OS_ALPINE, FdoDetect("alpine"))
 OsDetect.register_default(OS_ARCH, Arch())
@@ -731,8 +745,8 @@ OsDetect.register_default(OS_MANJARO, Manjaro())
 OsDetect.register_default(OS_CENTOS, Centos())
 OsDetect.register_default(OS_CYGWIN, Cygwin())
 OsDetect.register_default(OS_DEBIAN, Debian())
-OsDetect.register_default(OS_ELEMENTARY, LsbDetect('"elementary"'))
-OsDetect.register_default(OS_ELEMENTARY_OLD, LsbDetect('"elementary OS"'))
+OsDetect.register_default(OS_ELEMENTARY, LsbDetect("elementary"))
+OsDetect.register_default(OS_ELEMENTARY_OLD, LsbDetect("elementary OS"))
 OsDetect.register_default(OS_FEDORA, FdoDetect("fedora"))
 OsDetect.register_default(OS_FREEBSD, FreeBSD())
 OsDetect.register_default(OS_FUNTOO, Funtoo())
@@ -743,7 +757,8 @@ OsDetect.register_default(OS_MX, LsbDetect("MX"))
 OsDetect.register_default(OS_NEON, LsbDetect("neon"))
 OsDetect.register_default(OS_OPENEMBEDDED, OpenEmbedded())
 OsDetect.register_default(OS_OPENSUSE, OpenSuse())
-OsDetect.register_default(OS_OPENSUSE13, OpenSuse(brand_file='/etc/SUSE-brand'))
+OsDetect.register_default(OS_OPENSUSE13, OpenSuse(brand_file='/etc/SUSE-brand', release_file=None))
+OsDetect.register_default(OS_OPENSUSE, FdoDetect("opensuse-tumbleweed"))
 OsDetect.register_default(OS_OPENSUSE, FdoDetect("opensuse"))
 OsDetect.register_default(OS_TIZEN, FdoDetect("tizen"))
 OsDetect.register_default(OS_OSX, OSX())
@@ -754,6 +769,7 @@ OsDetect.register_default(OS_UBUNTU, LsbDetect("Ubuntu"))
 OsDetect.register_default(OS_CLEARLINUX, FdoDetect("clear-linux-os"))
 OsDetect.register_default(OS_NIXOS, FdoDetect("nixos"))
 OsDetect.register_default(OS_WINDOWS, Windows())
+OsDetect.register_default(OS_ZORIN, LsbDetect("Zorin"))
 
 
 if __name__ == '__main__':
