@@ -30,10 +30,12 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import absolute_import
+
 import os
-import sys
-import unittest
+
 import mock
+from mock import patch
 
 
 class TrueOs():
@@ -72,7 +74,7 @@ class FalseOs(object):
 def test__read_stdout():
     from rospkg.os_detect import _read_stdout
     assert 'hello' == _read_stdout(['echo', 'hello'])
-    assert None == _read_stdout(['bad-command-input-for-rospkg-os-detect'])
+    assert _read_stdout(['bad-command-input-for-rospkg-os-detect']) is None
 
 
 def test_tripwire_ubuntu():
@@ -99,11 +101,17 @@ def test_LsbDetect():
         pass
 
     # test match
-    import platform
-    platform.linux_distribution = mock.Mock()
-    platform.linux_distribution.return_value = ('Ubuntu', '10.04', 'lucid')
-    platform.dist = mock.Mock()
-    platform.dist.return_value = ('Ubuntu', '10.04', 'lucid')
+    # to be removed after Ubuntu Xenial is out of support
+    import sys
+    if sys.version_info >= (3, 8):
+        import distro
+    else:
+        import platform as distro
+
+    distro.linux_distribution = mock.Mock()
+    distro.linux_distribution.return_value = ('Ubuntu', '10.04', 'lucid')
+    distro.dist = mock.Mock()
+    distro.dist.return_value = ('Ubuntu', '10.04', 'lucid')
 
     detect = LsbDetect('Ubuntu')
     assert detect.is_os(), "should be Ubuntu"
@@ -153,10 +161,12 @@ def test_tripwire_osx():
     os_detect = OsDetect()
     os_detect.get_detector('osx')
 
-from mock import patch
-
 
 def test_osx():
+    if 'posix' != os.name:
+        from unittest.case import SkipTest
+        raise SkipTest('Test requires POSIX platform, not "{}"'.format(os.name))
+
     from rospkg.os_detect import OSX, _osx_codename, OsNotDetected
     test_dir = os.path.join(get_test_dir(), 'osx')
     detect = OSX(os.path.join(test_dir, "sw_vers"))
@@ -237,6 +247,41 @@ def test_arch():
     test()
 
 
+def test_tripwire_manjaro():
+    from rospkg.os_detect import OsDetect
+    os_detect = OsDetect()
+    os_detect.get_detector('manjaro')
+
+
+def test_manjaro():
+    from rospkg.os_detect import Manjaro, OsNotDetected
+    test_dir = os.path.join(get_test_dir(), 'manjaro')
+    detect = Manjaro(os.path.join(test_dir, "manjaro-release"))
+    assert detect.is_os()
+    assert detect.get_version() == ''
+
+    detect = Manjaro()
+    if not detect.is_os():
+        try:
+            detect.get_version()
+            assert False
+        except OsNotDetected:
+            pass
+        try:
+            detect.get_codename()
+            assert False
+        except OsNotDetected:
+            pass
+
+    @patch.object(Manjaro, 'is_os')
+    def test(mock):
+        mock.is_os.return_value = True
+        detect = Manjaro()
+        assert detect.get_version() == ''
+        assert detect.get_codename() == ''
+    test()
+
+
 def test_tripwire_opensuse():
     from rospkg.os_detect import OsDetect
     os_detect = OsDetect()
@@ -336,10 +381,10 @@ def test_fedora():
 
 def test_read_issue():
     from rospkg.os_detect import read_issue
-    assert read_issue('/fake/file') == None
+    assert read_issue('/fake/file') is None
     test_dir = os.path.join(get_test_dir(), 'rhel')
     assert read_issue(os.path.join(test_dir, 'issue')) == \
-    ['Red', 'Hat', 'Enterprise', 'Linux', 'AS', 'release', '3', '(Taroon)']
+        ['Red', 'Hat', 'Enterprise', 'Linux', 'AS', 'release', '3', '(Taroon)']
 
 
 def test_OsDetector():
@@ -446,7 +491,7 @@ def test_tripwire_freebsd():
 
 def test_freebsd():
     from rospkg.os_detect import FreeBSD, OsNotDetected
-    #TODO
+    # TODO
     if 0:
         test_dir = os.path.join(get_test_dir(), 'freebsd')
         release_file, issue_file = [os.path.join(test_dir, x) for
@@ -488,7 +533,7 @@ def test_freebsd():
 
 def test_cygwin():
     from rospkg.os_detect import Cygwin, OsNotDetected
-    #TODO
+    # TODO
     detect = Cygwin()
     if not detect.is_os():
         try:
@@ -635,7 +680,7 @@ def xTrueOsDetect_second_of_many():
 
 
 def xTrueOsDetect_last_of_many():
-    osa = roslib.os_detect.OSDetect([FalseOs(), FalseOs(), FalseOs(), FalseOs(), TrueOs(),])
+    osa = roslib.os_detect.OSDetect([FalseOs(), FalseOs(), FalseOs(), FalseOs(), TrueOs()])
     assert "os_name", osa.get_name()
     assert "os_version", osa.get_version()
     os_class = osa.get_os()
